[dpdk-dev] [PATCH] openssl pmd: rename SW crypto device from libcrypto to openssl

2016-10-20 Thread De Lara Guarch, Pablo


> -Original Message-
> From: dev [mailto:dev-bounces at dpdk.org] On Behalf Of Jain, Deepak K
> Sent: Wednesday, October 19, 2016 1:27 AM
> To: Mrozowicz, SlawomirX; Doherty, Declan
> Cc: dev at dpdk.org; Mrozowicz, SlawomirX
> Subject: Re: [dpdk-dev] [PATCH] openssl pmd: rename SW crypto device from
> libcrypto to openssl
> 
> 
> 
> > -Original Message-
> > From: dev [mailto:dev-bounces at dpdk.org] On Behalf Of Slawomir
> > Mrozowicz
> > Sent: Tuesday, October 18, 2016 12:36 PM
> > To: Doherty, Declan 
> > Cc: dev at dpdk.org; Mrozowicz, SlawomirX
> > 
> > Subject: [dpdk-dev] [PATCH] openssl pmd: rename SW crypto device from
> > libcrypto to openssl
> >
> > This patch replaces name "libcrypto" to "openssl" from file directories,
> > symbol prefixes and sub-names connected with old name.
> > Renamed poll mode driver files, test files, and documentations.
> > It is done to better name association with library because
> > the cryptography operations are using Openssl library crypto API.
> >
> > Fixes: d61f70b4c918 ("crypto/libcrypto: add driver for OpenSSL library")
> >
> > Signed-off-by: Slawomir Mrozowicz 
> > ---
> >  MAINTAINERS|6 +-
> >  app/test/test_cryptodev.c  |   56 +-
> >  app/test/test_cryptodev_aes_test_vectors.h |   62 +-
> >  app/test/test_cryptodev_blockcipher.c  |6 +-
> >  app/test/test_cryptodev_blockcipher.h  |2 +-
> >  app/test/test_cryptodev_des_test_vectors.h |   56 +-
> >  app/test/test_cryptodev_hash_test_vectors.h|   48 +-
> >  app/test/test_cryptodev_perf.c |   52 +-
> >  config/common_base |4 +-
> >  delete mode 100644
> > drivers/crypto/libcrypto/rte_pmd_libcrypto_version.map
> >  create mode 100644 drivers/crypto/openssl/Makefile
> >  create mode 100644 drivers/crypto/openssl/rte_openssl_pmd.c
> >  create mode 100644 drivers/crypto/openssl/rte_openssl_pmd_ops.c
> >  create mode 100644 drivers/crypto/openssl/rte_openssl_pmd_private.h
> >  create mode 100644
> drivers/crypto/openssl/rte_pmd_openssl_version.map
> >
> > diff --git a/MAINTAINERS b/MAINTAINERS
> > index 8f5fa82..af47e04 100644
> > --- a/MAINTAINERS
> > +++ b/MAINTAINERS
> > --
> > 2.5.0
> Acked-by: Deepak Kumar Jain 

Applied to dpdk-next-crypto.
Thanks,

Pablo


[dpdk-dev] [PATCH] openssl pmd: rename SW crypto device from libcrypto to openssl

2016-10-19 Thread Jain, Deepak K


> -Original Message-
> From: dev [mailto:dev-bounces at dpdk.org] On Behalf Of Slawomir
> Mrozowicz
> Sent: Tuesday, October 18, 2016 12:36 PM
> To: Doherty, Declan 
> Cc: dev at dpdk.org; Mrozowicz, SlawomirX
> 
> Subject: [dpdk-dev] [PATCH] openssl pmd: rename SW crypto device from
> libcrypto to openssl
> 
> This patch replaces name "libcrypto" to "openssl" from file directories,
> symbol prefixes and sub-names connected with old name.
> Renamed poll mode driver files, test files, and documentations.
> It is done to better name association with library because
> the cryptography operations are using Openssl library crypto API.
> 
> Fixes: d61f70b4c918 ("crypto/libcrypto: add driver for OpenSSL library")
> 
> Signed-off-by: Slawomir Mrozowicz 
> ---
>  MAINTAINERS|6 +-
>  app/test/test_cryptodev.c  |   56 +-
>  app/test/test_cryptodev_aes_test_vectors.h |   62 +-
>  app/test/test_cryptodev_blockcipher.c  |6 +-
>  app/test/test_cryptodev_blockcipher.h  |2 +-
>  app/test/test_cryptodev_des_test_vectors.h |   56 +-
>  app/test/test_cryptodev_hash_test_vectors.h|   48 +-
>  app/test/test_cryptodev_perf.c |   52 +-
>  config/common_base |4 +-
>  delete mode 100644
> drivers/crypto/libcrypto/rte_pmd_libcrypto_version.map
>  create mode 100644 drivers/crypto/openssl/Makefile
>  create mode 100644 drivers/crypto/openssl/rte_openssl_pmd.c
>  create mode 100644 drivers/crypto/openssl/rte_openssl_pmd_ops.c
>  create mode 100644 drivers/crypto/openssl/rte_openssl_pmd_private.h
>  create mode 100644 drivers/crypto/openssl/rte_pmd_openssl_version.map
> 
> diff --git a/MAINTAINERS b/MAINTAINERS
> index 8f5fa82..af47e04 100644
> --- a/MAINTAINERS
> +++ b/MAINTAINERS
> --
> 2.5.0
Acked-by: Deepak Kumar Jain 


[dpdk-dev] [PATCH] openssl pmd: rename SW crypto device from libcrypto to openssl

2016-10-18 Thread Slawomir Mrozowicz
This patch replaces name "libcrypto" to "openssl" from file directories,
symbol prefixes and sub-names connected with old name.
Renamed poll mode driver files, test files, and documentations.
It is done to better name association with library because
the cryptography operations are using Openssl library crypto API.

Fixes: d61f70b4c918 ("crypto/libcrypto: add driver for OpenSSL library")

Signed-off-by: Slawomir Mrozowicz 
---
 MAINTAINERS|6 +-
 app/test/test_cryptodev.c  |   56 +-
 app/test/test_cryptodev_aes_test_vectors.h |   62 +-
 app/test/test_cryptodev_blockcipher.c  |6 +-
 app/test/test_cryptodev_blockcipher.h  |2 +-
 app/test/test_cryptodev_des_test_vectors.h |   56 +-
 app/test/test_cryptodev_hash_test_vectors.h|   48 +-
 app/test/test_cryptodev_perf.c |   52 +-
 config/common_base |4 +-
 doc/guides/cryptodevs/index.rst|2 +-
 doc/guides/cryptodevs/libcrypto.rst|  117 ---
 doc/guides/cryptodevs/openssl.rst  |  117 +++
 doc/guides/rel_notes/release_16_11.rst |2 +-
 drivers/crypto/Makefile|2 +-
 drivers/crypto/libcrypto/Makefile  |   60 --
 drivers/crypto/libcrypto/rte_libcrypto_pmd.c   | 1062 
 drivers/crypto/libcrypto/rte_libcrypto_pmd_ops.c   |  708 -
 .../crypto/libcrypto/rte_libcrypto_pmd_private.h   |  174 
 .../crypto/libcrypto/rte_pmd_libcrypto_version.map |3 -
 drivers/crypto/openssl/Makefile|   60 ++
 drivers/crypto/openssl/rte_openssl_pmd.c   | 1062 
 drivers/crypto/openssl/rte_openssl_pmd_ops.c   |  708 +
 drivers/crypto/openssl/rte_openssl_pmd_private.h   |  174 
 drivers/crypto/openssl/rte_pmd_openssl_version.map |3 +
 lib/librte_cryptodev/rte_cryptodev.h   |4 +-
 mk/rte.app.mk  |2 +-
 26 files changed, 2276 insertions(+), 2276 deletions(-)
 delete mode 100644 doc/guides/cryptodevs/libcrypto.rst
 create mode 100644 doc/guides/cryptodevs/openssl.rst
 delete mode 100644 drivers/crypto/libcrypto/Makefile
 delete mode 100644 drivers/crypto/libcrypto/rte_libcrypto_pmd.c
 delete mode 100644 drivers/crypto/libcrypto/rte_libcrypto_pmd_ops.c
 delete mode 100644 drivers/crypto/libcrypto/rte_libcrypto_pmd_private.h
 delete mode 100644 drivers/crypto/libcrypto/rte_pmd_libcrypto_version.map
 create mode 100644 drivers/crypto/openssl/Makefile
 create mode 100644 drivers/crypto/openssl/rte_openssl_pmd.c
 create mode 100644 drivers/crypto/openssl/rte_openssl_pmd_ops.c
 create mode 100644 drivers/crypto/openssl/rte_openssl_pmd_private.h
 create mode 100644 drivers/crypto/openssl/rte_pmd_openssl_version.map

diff --git a/MAINTAINERS b/MAINTAINERS
index 8f5fa82..af47e04 100644
--- a/MAINTAINERS
+++ b/MAINTAINERS
@@ -436,10 +436,10 @@ M: Pablo de Lara 
 F: drivers/crypto/zuc/
 F: doc/guides/cryptodevs/zuc.rst

-LibCrypto PMD
+OpenSSL PMD
 M: Declan Doherty 
-F: drivers/crypto/libcrypto/
-F: doc/guides/cryptodevs/libcrypto.rst
+F: drivers/crypto/openssl/
+F: doc/guides/cryptodevs/openssl.rst

 Null Crypto PMD
 M: Declan Doherty 
diff --git a/app/test/test_cryptodev.c b/app/test/test_cryptodev.c
index 7d03899..079e54d 100644
--- a/app/test/test_cryptodev.c
+++ b/app/test/test_cryptodev.c
@@ -326,24 +326,24 @@ testsuite_setup(void)
}
}

-   /* Create 2 LIBCRYPTO devices if required */
-   if (gbl_cryptodev_type == RTE_CRYPTODEV_LIBCRYPTO_PMD) {
-#ifndef RTE_LIBRTE_PMD_LIBCRYPTO
-   RTE_LOG(ERR, USER1, "CONFIG_RTE_LIBRTE_PMD_LIBCRYPTO must be"
+   /* Create 2 OPENSSL devices if required */
+   if (gbl_cryptodev_type == RTE_CRYPTODEV_OPENSSL_PMD) {
+#ifndef RTE_LIBRTE_PMD_OPENSSL
+   RTE_LOG(ERR, USER1, "CONFIG_RTE_LIBRTE_PMD_OPENSSL must be"
" enabled in config file to run this testsuite.\n");
return TEST_FAILED;
 #endif
nb_devs = rte_cryptodev_count_devtype(
-   RTE_CRYPTODEV_LIBCRYPTO_PMD);
+   RTE_CRYPTODEV_OPENSSL_PMD);
if (nb_devs < 2) {
for (i = nb_devs; i < 2; i++) {
ret = rte_eal_vdev_init(
-   RTE_STR(CRYPTODEV_NAME_LIBCRYPTO_PMD),
+   RTE_STR(CRYPTODEV_NAME_OPENSSL_PMD),
NULL);

TEST_ASSERT(ret == 0, "Failed to create "
"instance %u of pmd : %s", i,
-   RTE_STR(CRYPTODEV_NAME_LIBCRYPTO_PMD));
+   RTE_STR(CRYPTODEV_NAME_OPENSSL_PMD));